# Kindly

_Context aware curator of workflows_

General tools, while applicable in more situations, are typically less useful in each.
Kindly uses two cues to provide shortcuts to tools that are useful right now:
* python environment
* working directory
